pub struct Liveness { /* private fields */ }Expand description
Liveness analysis results for a function.
Implementations
Sourceimpl Liveness
impl Liveness
Sourcepub fn live_in(&self, block: BlockId) -> &LiveSet
pub fn live_in(&self, block: BlockId) -> &LiveSet
Returns the values live at the entry of a block.
Sourcepub fn live_out(&self, block: BlockId) -> &LiveSet
pub fn live_out(&self, block: BlockId) -> &LiveSet
Returns the values live at the exit of a block.
Sourcepub fn live_at_inst(
&self,
func: &Function,
block_id: BlockId,
inst_idx: usize,
) -> LivenessInfo
pub fn live_at_inst( &self, func: &Function, block_id: BlockId, inst_idx: usize, ) -> LivenessInfo
Computes liveness at a specific instruction within a block. Returns values live before and after the instruction.
Sourcepub fn last_use_in_block(
&self,
val: ValueId,
block: BlockId,
) -> Option<Option<usize>>
pub fn last_use_in_block( &self, val: ValueId, block: BlockId, ) -> Option<Option<usize>>
Returns the last use location of a value within a specific block, if any.
Returns Some(Some(inst_idx)) if last used at an instruction,
Some(None) if last used in a terminator,
None if the value is not used in this block.
Sourcepub fn is_dead_after(
&self,
val: ValueId,
block: BlockId,
inst_idx: usize,
) -> bool
pub fn is_dead_after( &self, val: ValueId, block: BlockId, inst_idx: usize, ) -> bool
Returns true if the value is dead after the given instruction in the given block.
A value is dead after an instruction if:
- The instruction is the last use of the value within this block, AND
- The value is NOT in live_out (meaning no successor blocks use it)