pub struct LoopInfo {
pub loops: FxHashMap<BlockId, Loop>,
pub block_to_loop: FxHashMap<BlockId, BlockId>,
}Expand description
Result of loop analysis for a function.
Fields
loops: FxHashMap<BlockId, Loop>All loops in the function, keyed by header block.
block_to_loop: FxHashMap<BlockId, BlockId>Mapping from block to the innermost loop containing it.
Implementations