pub struct Validator;Expand description
MIR validation query.
Implementations
Sourceimpl Validator
impl Validator
Sourcepub fn validate_function(func: &Function) -> Vec<ValidationError>
pub fn validate_function(func: &Function) -> Vec<ValidationError>
Validates a single function. Returns the empty vec on success.
Sourcepub fn validate_module(module: &Module) -> Vec<ValidationError>
pub fn validate_module(module: &Module) -> Vec<ValidationError>
Validates every function in a module. Errors from each function are prefixed with the function index in the message so they can be distinguished in mixed reports.