pub enum MirType {
UInt(u16),
Int(u16),
Bool,
Address,
FixedBytes(u8),
MemPtr,
StoragePtr,
CalldataPtr,
Function,
Void,
}Expand description
Types used in MIR.
Variants
UInt(u16)
Unsigned integer with a given bit width (8, 16, 32, …, 256).
Int(u16)
Signed integer with a given bit width.
Bool
Boolean type.
Address
Address type (20 bytes).
FixedBytes(u8)
Fixed-size byte array.
MemPtr
Memory pointer.
StoragePtr
Storage pointer.
CalldataPtr
Calldata pointer.
Function
Function type.
Void
Void/unit type (for functions that don’t return).
Implementations
Sourceimpl MirType
impl MirType
Sourcepub const fn stack_size(&self) -> usize
pub const fn stack_size(&self) -> usize
Returns the size in bytes for this type on the stack.
Sourcepub const fn fits_in_word(&self) -> bool
pub const fn fits_in_word(&self) -> bool
Returns true if this type fits in a single EVM word (32 bytes).