parse_module

Function parse_module 

pub fn parse_module(input: &str) -> Result<Module, ParseError>
Parses a textual MIR module.

Errors

Returns a ParseError if the input does not conform to the MIR textual format produced by Module::to_text.

Session

Must be called inside an active solar_interface::Session::enter, because module and function names are interned via Symbol::intern.