pub struct FunctionId(/* private fields */);Expand description
A unique identifier for a function in the MIR.
Implementations
Sourceimpl FunctionId
impl FunctionId
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub fn from_foreign<F: Idx>(value: F) -> Self
pub fn from_foreign<F: Idx>(value: F) -> Self
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> Self
pub const unsafe fn from_usize_unchecked(value: usize) -> Self
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> Self
pub const unsafe fn from_raw_unchecked(raw: u32) -> Self
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> Self
pub const fn from_usize(value: usize) -> Self
Sourceimpl FunctionId
impl FunctionId