InstructionMetadata

Struct InstructionMetadata 

pub struct InstructionMetadata {
    pub loop_depth: u16,
    /* private fields */
}
Extra information attached to a MIR instruction by lowering or analysis passes.

Fields

loop_depth: u16

Loop nesting depth attached by loop-aware analyses.

Implementations

Source

impl InstructionMetadata

pub const EMPTY: Self

Empty instruction metadata.

pub fn storage_alias(&self) -> Option<StorageAlias>

Returns the proven storage alias key.

pub fn set_storage_alias(&mut self, alias: Option<StorageAlias>)

Sets the proven storage alias key.

pub fn hir_expr(&self) -> Option<ExprId>

Returns the HIR expression that produced this instruction.

pub fn set_hir_expr(&mut self, expr: Option<ExprId>)

Sets the HIR expression that produced this instruction.

pub fn source_span(&self) -> Option<Span>

Returns the source span that produced this instruction.

pub fn set_source_span(&mut self, span: Option<Span>)

Sets the source span that produced this instruction.

pub fn memory_region(&self) -> Option<MemoryRegion>

Returns the proven memory region.

pub fn set_memory_region(&mut self, region: Option<MemoryRegion>)

Sets the proven memory region.

pub fn unchecked(&self) -> bool

Returns whether this instruction was lowered from an unchecked arithmetic context.

pub fn set_unchecked(&mut self, unchecked: bool)

Sets whether this instruction was lowered from an unchecked arithmetic context.

pub fn effect(&self) -> Option<EffectKind>

Returns the conservative effect classification attached by lowering or analysis.

pub fn set_effect(&mut self, effect: Option<EffectKind>)

Sets the conservative effect classification attached by lowering or analysis.