pub struct CfgSimplifyStats {
pub blocks_merged: usize,
pub empty_blocks_eliminated: usize,
pub terminators_simplified: usize,
pub trivial_phis_simplified: usize,
pub terminal_blocks_deduplicated: usize,
pub dead_functions_eliminated: usize,
pub gas_saved: usize,
}Expand description
Statistics from CFG simplification.
Fields
blocks_merged: usizeNumber of blocks merged.
empty_blocks_eliminated: usizeNumber of empty blocks eliminated.
terminators_simplified: usizeNumber of degenerate terminators simplified.
trivial_phis_simplified: usizeNumber of trivial phi nodes replaced by their unique incoming value.
terminal_blocks_deduplicated: usizeNumber of identical terminal blocks merged into one shared block.
dead_functions_eliminated: usizeNumber of dead functions eliminated.
gas_saved: usizeEstimated gas saved (8 gas per eliminated jump).
Implementations