pub struct DeadCodeEliminator {
pub eliminated_count: usize,
pub blocks_removed: usize,
pub unused_params: usize,
}Expand description
Dead Code Elimination pass.
Removes instructions that:
- Have a result that is never used
- Have no side effects
- Are in unreachable blocks
- Are instructions after a terminator (unreachable code)
Side-effect instructions (SSTORE, MSTORE, CALL, LOG, etc.) are always kept.
Fields
eliminated_count: usizeNumber of instructions eliminated in the last run.
blocks_removed: usizeNumber of unreachable blocks removed.
unused_params: usizeNumber of unused parameters detected.
Implementations
Sourceimpl DeadCodeEliminator
impl DeadCodeEliminator
Sourcepub fn run(&mut self, func: &mut Function) -> usize
pub fn run(&mut self, func: &mut Function) -> usize
Runs dead code elimination on a function. Returns the number of instructions eliminated.
Sourcepub fn run_with_stats(&mut self, func: &mut Function) -> DceStats
pub fn run_with_stats(&mut self, func: &mut Function) -> DceStats
Runs dead code elimination with full statistics.
Sourcepub fn run_to_fixpoint(&mut self, func: &mut Function) -> usize
pub fn run_to_fixpoint(&mut self, func: &mut Function) -> usize
Runs dead code elimination iteratively until no more changes.
Sourcepub fn find_unused_parameters(&self, func: &Function) -> Vec<u32>
pub fn find_unused_parameters(&self, func: &Function) -> Vec<u32>
Finds unused function parameters. Returns the indices of parameters that are never used.