pub struct InstructionMetadata {
pub loop_depth: u16,
/* private fields */
}Expand description
Extra information attached to a MIR instruction by lowering or analysis passes.
Fields
loop_depth: u16Loop nesting depth attached by loop-aware analyses.
Implementations
Sourceimpl InstructionMetadata
impl InstructionMetadata
Sourcepub fn storage_alias(&self) -> Option<StorageAlias>
pub fn storage_alias(&self) -> Option<StorageAlias>
Returns the proven storage alias key.
Sourcepub fn set_storage_alias(&mut self, alias: Option<StorageAlias>)
pub fn set_storage_alias(&mut self, alias: Option<StorageAlias>)
Sets the proven storage alias key.
Sourcepub fn hir_expr(&self) -> Option<ExprId>
pub fn hir_expr(&self) -> Option<ExprId>
Returns the HIR expression that produced this instruction.
Sourcepub fn set_hir_expr(&mut self, expr: Option<ExprId>)
pub fn set_hir_expr(&mut self, expr: Option<ExprId>)
Sets the HIR expression that produced this instruction.
Sourcepub fn source_span(&self) -> Option<Span>
pub fn source_span(&self) -> Option<Span>
Returns the source span that produced this instruction.
Sourcepub fn set_source_span(&mut self, span: Option<Span>)
pub fn set_source_span(&mut self, span: Option<Span>)
Sets the source span that produced this instruction.
Sourcepub fn memory_region(&self) -> Option<MemoryRegion>
pub fn memory_region(&self) -> Option<MemoryRegion>
Returns the proven memory region.
Sourcepub fn set_memory_region(&mut self, region: Option<MemoryRegion>)
pub fn set_memory_region(&mut self, region: Option<MemoryRegion>)
Sets the proven memory region.
Sourcepub fn unchecked(&self) -> bool
pub fn unchecked(&self) -> bool
Returns whether this instruction was lowered from an unchecked arithmetic context.
Sourcepub fn set_unchecked(&mut self, unchecked: bool)
pub fn set_unchecked(&mut self, unchecked: bool)
Sets whether this instruction was lowered from an unchecked arithmetic context.
Sourcepub fn effect(&self) -> Option<EffectKind>
pub fn effect(&self) -> Option<EffectKind>
Returns the conservative effect classification attached by lowering or analysis.
Sourcepub fn set_effect(&mut self, effect: Option<EffectKind>)
pub fn set_effect(&mut self, effect: Option<EffectKind>)
Sets the conservative effect classification attached by lowering or analysis.